document.addEventListener('DOMContentLoaded', () => {
    const urlInput = document.getElementById('urlInput');
    const fetchButton = document.getElementById('fetchButton');
    const htmlOutput = document.getElementById('htmlOutput');

    fetchButton.addEventListener('click', async () => {
        const url = urlInput.value.trim();
        
        if (!url) {
            htmlOutput.textContent = 'Please enter a valid URL';
            return;
        }

        try {
            htmlOutput.textContent = 'Loading...';
            
            const response = await fetch(url);
            if (!response.ok) throw new Error('Failed to fetch');
            
            const text = await response.text();
            
            // Basic HTML syntax highlighting
            const highlightedHtml = text
                .replace(/</g, '&lt;')
                .replace(/>/g, '&gt;')
                .replace(/(&lt;[^&]*&gt;)/g, '<span style="color: #2563eb">$1</span>')
                .replace(/("[^"]*")/g, '<span style="color: #059669">$1</span>');
            
            htmlOutput.innerHTML = highlightedHtml;
        } catch (error) {
            htmlOutput.textContent = `Error: ${error.message}. Note: Some websites may block direct access due to CORS policies.`;
        }
    });

    // Enable Enter key submission
    urlInput.addEventListener('keypress', (e) => {
        if (e.key === 'Enter') {
            fetchButton.click();
        }
    });
});